bool can be a reserved keyword. Daniel

* debugXML.c include/libxml/debugXML.h: bool can be a reserved
  keyword.
Daniel
diff --git a/debugXML.c b/debugXML.c
index b1461a9..bbda5d7 100644
--- a/debugXML.c
+++ b/debugXML.c
@@ -1162,14 +1162,14 @@
 
 /**
  * xmlBoolToText:
  * @bool : a bool to turn into text
  *
  * Convenient way to turn bool into text 
 */
 const char *
-xmlBoolToText(int bool)
+xmlBoolToText(int boolval)
 {
-    if (bool)
+    if (boolval)
         return("True");
     else
         return("False");
@@ -1162,14 +1162,14 @@
 /**
  * xmlBoolToText:
- * @bool : a bool to turn into text
+ * @boolval : a bool to turn into text
  *
  * Convenient way to turn bool into text 